@@ -41,6 +41,16 @@ class Macro(metaclass=SingletonType):
         time.sleep(2)
         window.hide()
 
+    def add_command_to_all(self, condition, func):
+        """
+        向所有现有配置中添加同一命令
+        :param condition:
+        :param func:
+        :return:
+        """
+        for config in self.__core.get_configs().values():
+            config.add_command(condition, func)
+
     def add_config(self, config):
         """
         添加配置
