@@ -1,5 +1,6 @@
 import tkinter as tk
 import tkinter.font as tf
+from tkinter import ttk
 from tkinter import messagebox
 from tkinter.filedialog import askopenfilename, askdirectory
 import time
@@ -124,43 +125,13 @@ class Notification(metaclass=SingletonType):
     visible = property(get_visible, set_visible)
 
 
-class InputBox:
-    """
-    参数输入框类
-    """
-    def __init__(self, title='输入框', normal=None, file=None, dir=None):
-        """
-        初始化实例
-        :param title: 对话框标题
-        :param normal: 普通参数，皆为string类型
-        :param file: 文件地址参数，通过文件选择对话框输入
-        :param dir: 文件夹地址参数，通过文件夹选择对话框输入
-        """
-        self.title = title
-        self.normal = normal
-        self.file = file
-        self.dir = dir
-
-        if self.normal is None:
-            self.normal = []
-        if self.file is None:
-            self.file = []
-        if self.dir is None:
-            self.dir = []
-
-        self.top = None
-        self.entries = []
-        self.vars = []
-
-        # 输入框中输入的参数值，顺序按照normal、file、dir的数序依次排列
-        self.values = []
-
-    def show(self):
-        """
-        显示输入对话框
-        :return: 输入的参数列表
-        """
-        return self.top_window()
+class InputField:
+    def __init__(self, name, type='entry', default=None, options=None, focus=False):
+        self.name = name
+        self.type = type
+        self.default = default
+        self.options = options
+        self.focus = focus
 
     @staticmethod
     def select_file(var):
@@ -172,9 +143,70 @@ class InputBox:
         dirpath = askdirectory()
         var.set(dirpath)
 
+    def draw_frame(self, window):
+        var = tk.StringVar()
+        frame = tk.Frame(window, takefocus=True)
+        frame.pack(fill=tk.X, padx=10, pady=2, expand=1)
+        tk.Label(frame, text=self.name).pack(side=tk.TOP, anchor=tk.W)
+        if self.type == 'entry':
+            widget = tk.Entry(frame, show=None, textvariable=var)
+            widget.pack(fill=tk.X, side=tk.TOP)
+            if self.default is not None:
+                var.set(self.default)
+        elif self.type == 'file':
+            widget = tk.Entry(frame, show=None, textvariable=var, state=tk.DISABLED)
+            widget.pack(fill=tk.X, side=tk.LEFT, expand=1)
+            tk.Button(frame, text='选择文件', command=lambda var=var: self.select_file(var)) \
+                .pack(fill=tk.X, side=tk.LEFT)
+            if self.default is not None:
+                var.set(self.default)
+        elif self.type == 'dir':
+            widget = tk.Entry(frame, show=None, textvariable=var, state=tk.DISABLED)
+            widget.pack(fill=tk.X, side=tk.LEFT, expand=1)
+            tk.Button(frame, text='选择文件夹', command=lambda var=var: self.select_dir(var)) \
+                .pack(fill=tk.X, side=tk.LEFT)
+            if self.default is not None:
+                var.set(self.default)
+        elif self.type == 'combobox':
+            widget = ttk.Combobox(frame, textvariable=var)
+            widget['values'] = self.options
+            widget.pack(fill=tk.X, side=tk.TOP)
+            if self.default is None:
+                widget.current(0)
+            else:
+                widget.current(self.default)
+        else:
+            raise ValueError('there is no such type,select in "entry","file","dir" or "combobox"')
+        if self.focus:
+            widget.focus_set()
+        return var
+
+
+class InputBox:
+    """
+    参数输入框类
+    """
+    def __init__(self, title='输入框', *args):
+        """
+        初始化实例
+        :param title: 对话框标题
+        """
+        self.title = title
+        self.__args = args
+
+        self.top = None
+        self.vars = []
+
+        self.values = []
+
+    def show(self):
+        """
+        显示输入对话框
+        :return: 输入的参数列表
+        """
+        return self.top_window()
+
     def clear_all(self):
-        for entry in self.entries:
-            entry.delete(0, tk.END)
         for var in self.vars:
             var.set('')
 
@@ -182,7 +214,7 @@ class InputBox:
         if flag:
             self.values = None
         else:
-            self.values = [item.get() for item in self.entries]
+            self.values = [var.get() for var in self.vars]
         self.top.destroy()
 
     def top_window(self):
@@ -197,38 +229,14 @@ class InputBox:
         screen_width = self.top.winfo_screenwidth()
         screen_height = self.top.winfo_screenheight()
         width = 300
-        height = ((len(self.normal) + len(self.file) + len(self.dir)) * 2 + 1) * 30
+        height = (len(self.__args) * 2 + 1) * 30
         self.top.geometry('{}x{}+{}+{}'
                           .format(width, height, (screen_width - width) // 2, (screen_height - height) // 2))
 
-        for param in self.normal:
-            frame = tk.Frame(self.top, takefocus=True)
-            frame.pack(fill=tk.X, padx=10, pady=2, expand=1)
-            tk.Label(frame, text=param).pack(side=tk.TOP, anchor=tk.W)
-            self.entries.append(tk.Entry(frame, show=None))
-            self.entries[-1].pack(fill=tk.X, side=tk.TOP)
-
-        for param in self.file:
-            self.vars.append(tk.StringVar())
-            frame = tk.Frame(self.top, takefocus=True)
-            frame.pack(fill=tk.X, padx=10, pady=2, expand=1)
-            tk.Label(frame, text=param).pack(side=tk.TOP, anchor=tk.W)
-            self.entries.append(tk.Entry(frame, show=None, textvariable=self.vars[-1], state=tk.DISABLED))
-            self.entries[-1].pack(fill=tk.X, side=tk.TOP)
-            self.entries[-1].pack(fill=tk.X, side=tk.LEFT, expand=1)
-            tk.Button(frame, text='选择文件', command=lambda var=self.vars[-1]: self.select_file(var)) \
-                .pack(fill=tk.X, side=tk.LEFT)
-
-        for param in self.dir:
-            self.vars.append(tk.StringVar())
-            frame = tk.Frame(self.top, takefocus=True)
-            frame.pack(fill=tk.X, padx=10, pady=2, expand=1)
-            tk.Label(frame, text=param).pack(side=tk.TOP, anchor=tk.W)
-            self.entries.append(tk.Entry(frame, show=None, textvariable=self.vars[-1], state=tk.DISABLED))
-            self.entries[-1].pack(fill=tk.X, side=tk.TOP)
-            self.entries[-1].pack(fill=tk.X, side=tk.LEFT, expand=1)
-            tk.Button(frame, text='选择文件夹', command=lambda var=self.vars[-1]: self.select_dir(var)) \
-                .pack(fill=tk.X, side=tk.LEFT)
+        for field in self.__args:
+            if not isinstance(field, InputField):
+                raise TypeError('args must be <class InputField>')
+            self.vars.append(field.draw_frame(self.top))
 
         frame = tk.Frame(self.top, takefocus=True)
         frame.pack(fill=tk.X, padx=10, pady=2, expand=1)
@@ -244,18 +252,14 @@ class InputBox:
         self.top.deiconify()
         self.top.focus_force()
         self.top.focus_set()
-        self.entries[0].focus_set()
 
         self.top.wait_window()
         return self.values
 
 
-def input_box(normal=None, file=None, dir=None, title='输入框'):
+def input_box(*ags, title='输入框'):
     """
     参数输入框装饰器
-    :param normal:
-    :param file:
-    :param dir:
     :param title: 输入框标题
     :return:
     """
@@ -263,7 +267,7 @@ def input_box(normal=None, file=None, dir=None, title='输入框'):
         @wraps(f)
         def decorated(*args, **kwargs):
             time.sleep(SLEEP_TIME)
-            res = InputBox(title=title, normal=normal, file=file, dir=dir).show()
+            res = InputBox(title, *ags).show()
             if res is not None:
                 return f(*res)
         return decorated
